@@ -36,7 +36,6 @@ functions:
     * Choquet
     * Sugeno
     * ExpandKinteractive2Bit
-    * ExpandKinteractive2Bit_m
     * Shapley
     * Banzhaf
     * ShapleyMob
@@ -136,6 +135,7 @@ functions:
 
 
 
+import sys
 import numpy as np
 import types
 import math
@@ -369,19 +369,6 @@ def ExpandKinteractive2Bit(src, env, kint):
     return pout_destnp
 
 
-
-#    void py_ExpandKinteractive2Bit_m(double* out_dest, double* src, struct fm_env* env, int kint, int arraysize, double* out_VVC)
-def ExpandKinteractive2Bit_m(src, env, kint):
-    trace( "void py_ExpandKinteractive2Bit_m(double* out_dest, double* src, struct fm_env* env, int kint, int arraysize, double* out_VVC)")
-    pout_destnp, pout_dest = create_float_zeros_as_CFFI_double( env.m)
-    pout_VVCnp, pout_VVC = create_float_zeros_as_CFFI_double( env.m)
-    psrcnp, psrc = convert_py_float_to_cffi( src)
-    arraysize = fm.py_SizeArraykinteractive( env.n, kint, env)
-    fm.py_ExpandKinteractive2Bit_m( pout_dest, psrc, env, kint, arraysize, pout_VVC)
-    return pout_destnp, pout_VVCnp
-
-
-
 #    void py_Shapley(double* v, double* out_x, struct fm_env* env)
 def Shapley(v, env):
     trace( "void py_Shapley(double* v, double* out_x, struct fm_env* env)")
@@ -586,8 +573,6 @@ def FuzzyMeasureFitLPKinteractiveMarginal(datanum, additive, env, K, submod, dat
     fm.py_FuzzyMeasureFitLPKinteractiveMarginal( datanum, additive, env, pout_v, pdataset, pK, submod)
     return pout_vnp, dataset
 
-
-
 #    void py_FuzzyMeasureFitLPKinteractiveMarginalMaxChain(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, double* K, int* maxiters, int submod)
 def FuzzyMeasureFitLPKinteractiveMarginalMaxChain(datanum, additive, env, K, maxiters, submod, dataset = None):
     trace( "void py_FuzzyMeasureFitLPKinteractiveMarginalMaxChain(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, double* K, int* maxiters, int submod)")
